@@ -1,5 +1,5 @@
 /* Lattice Mico32-specific support for 32-bit ELF
-   Copyright (C) 2008-2025 Free Software Foundation, Inc.
+   Copyright (C) 2008-2026 Free Software Foundation, Inc.
    Contributed by Jon Beniston <jon@beniston.com>
 
    This file is part of BFD, the Binary File Descriptor library.
@@ -444,10 +444,10 @@ static const struct lm32_reloc_map lm32_reloc_map[] =
   { BFD_RELOC_LM32_16_GOT,	R_LM32_16_GOT },
   { BFD_RELOC_LM32_GOTOFF_HI16, R_LM32_GOTOFF_HI16 },
   { BFD_RELOC_LM32_GOTOFF_LO16, R_LM32_GOTOFF_LO16 },
-  { BFD_RELOC_LM32_COPY,	R_LM32_COPY },
-  { BFD_RELOC_LM32_GLOB_DAT,	R_LM32_GLOB_DAT },
-  { BFD_RELOC_LM32_JMP_SLOT,	R_LM32_JMP_SLOT },
-  { BFD_RELOC_LM32_RELATIVE,	R_LM32_RELATIVE },
+  { BFD_RELOC_COPY,		R_LM32_COPY },
+  { BFD_RELOC_GLOB_DAT,		R_LM32_GLOB_DAT },
+  { BFD_RELOC_JMP_SLOT,		R_LM32_JMP_SLOT },
+  { BFD_RELOC_RELATIVE,		R_LM32_RELATIVE },
 };
 
 static reloc_howto_type *
@@ -2201,7 +2201,7 @@ lm32_elf_create_dynamic_sections (bfd *abfd, struct bfd_link_info *info)
   struct elf_lm32_link_hash_table *htab;
   flagword flags, pltflags;
   asection *s;
-  const struct elf_backend_data *bed = get_elf_backend_data (abfd);
+  elf_backend_data *bed = get_elf_backend_data (abfd);
   int ptralign = 2; /* 32bit */
 
   htab = lm32_elf_hash_table (info);
