@@ -1,5 +1,5 @@
 /* tc-epiphany.h -- Header file for tc-epiphany.c.
-   Copyright (C) 2009-2025 Free Software Foundation, Inc.
+   Copyright (C) 2009-2026 Free Software Foundation, Inc.
    Contributed by Embecosm on behalf of Adapteva, Inc.
 
    This file is part of GAS, the GNU Assembler.
@@ -74,7 +74,7 @@ extern int epiphany_cgen_parse_fix_exp (int, expressionS *);
 
 #define HANDLE_ALIGN(s, f) epiphany_handle_align (f)
 extern void epiphany_handle_align (fragS *);
-#define MAX_MEM_FOR_RS_ALIGN_CODE (1 + 2)
+#define MAX_MEM_FOR_RS_ALIGN_CODE(p2align, max) (1 + 2)
 
 #define TARGET_FORMAT "elf32-epiphany"
 
