@@ -1,5 +1,5 @@
 /* ELF support for BFD.
-   Copyright (C) 1991-2025 Free Software Foundation, Inc.
+   Copyright (C) 1991-2026 Free Software Foundation, Inc.
 
    Written by Fred Fish @ Cygnus Support, from information published
    in "UNIX System V Release 4, Programmers Guide: ANSI C and
@@ -697,6 +697,8 @@
 #define NT_X86_SHSTK	0x204		/* x86 SHSTK state.  */
 					/* This replaces NT_X86_CET (0x203).  */
 					/*   note name must be "LINUX".  */
+#define NT_X86_XSAVE_LAYOUT	0x205	/* XSAVE layout description */
+					/*   note name must be "LINUX".  */
 #define NT_S390_HIGH_GPRS 0x300		/* S/390 upper halves of GPRs  */
 					/*   note name must be "LINUX".  */
 #define NT_S390_TIMER	0x301		/* S390 timer */
@@ -1455,6 +1457,8 @@
 #define AT_HWCAP2	26		/* Extension of AT_HWCAP.  */
 #define AT_RSEQ_FEATURE_SIZE	27	/* rseq supported feature size */
 #define AT_RSEQ_ALIGN	28		/* rseq allocation alignment */
+#define AT_HWCAP3	29		/* Extension of AT_HWCAP.  */
+#define AT_HWCAP4	30		/* Extension of AT_HWCAP.  */
 #define AT_EXECFN	31		/* Filename of executable.  */
 /* Pointer to the global system page used for system calls and other
    nice things.  */
